// Copyright (c) 2017, 2024, Oracle and/or its affiliates. All rights reserved.
// Licensed under the Mozilla Public License v2.0

variable "tenancy_ocid" {}
variable "user_ocid" {}
variable "fingerprint" {}
variable "private_key_path" {}
variable "region" {}
variable "compartment_id" {}
variable "ssh_public_key" {}

provider "oci" {
  tenancy_ocid     = "${var.tenancy_ocid}"
  user_ocid        = "${var.user_ocid}"
  fingerprint      = "${var.fingerprint}"
  private_key_path = "${var.private_key_path}"
  region           = "${var.region}"
}

variable defined_tag_namespace_name {
  default = ""
}

resource "oci_identity_tag_namespace" "tag-namespace1" {
  #Required
  compartment_id = "${var.tenancy_ocid}"
  description    = "example tag namespace"
  name           = "${var.defined_tag_namespace_name != "" ? var.defined_tag_namespace_name : "example-tag-namespace-all"}"

  is_retired = false
}

resource "oci_identity_tag" "tag1" {
  #Required
  description      = "example tag"
  name             = "example-tag"
  tag_namespace_id = "${oci_identity_tag_namespace.tag-namespace1.id}"

  is_retired = false
}

resource "oci_database_database_software_image" "test_database_software_image" {
  compartment_id                          = "${var.compartment_id}"
  database_software_image_one_off_patches = ["31113249", "27929509"]
  database_version                        = "19.0.0.0"
  defined_tags                            = "${map("${oci_identity_tag_namespace.tag-namespace1.name}.${oci_identity_tag.tag1.name}", "value")}"
  display_name                            = "image1"

  freeform_tags = {
    "Department" = "Finance"
  }

  image_shape_family = "VM_BM_SHAPE"
  image_type         = "DATABASE_IMAGE"

  ls_inventory = <<EOF
Local Machine Information::
Hostname: standard003.sub03202150310.test.oraclevcn.com
ARU platform id: 226
ARU platform description:: Linux x86-64

Installed Top-level Products (1):

Oracle Database 19c                                                  19.0.0.0.0
There are 1 products installed in this Oracle Home.


Interim patches (6) :

Patch  30484981     : applied on Thu Jan 09 06:21:51 UTC 2020
Unique Patch ID:  23248235
Patch description:  "OJVM RELEASE UPDATE: 19.6.0.0.200114 (30484981)"
   Created on 5 Dec 2019, 05:10:10 hrs PST8PDT
   Bugs fixed:
     29540327, 29254623, 29445548, 29774362, 30134746, 30160625, 29942275
     30534662, 29512125

Patch  30423135     : applied on Thu Jan 09 06:19:38 UTC 2020
Unique Patch ID:  23247953
Patch description:  "REINSTATE IS FAILING POST APPLYING 19C OCT19 PATCHES"
   Created on 5 Dec 2019, 05:12:58 hrs PST8PDT
   Bugs fixed:
     30423135
   This patch overlays patches:
     30557433, 29517242, 30557433, 29517242, 30557433
   This patch needs patches:
     30557433, 29517242, 30557433, 29517242, 30557433
   as prerequisites

Patch  30432118     : applied on Thu Jan 09 06:19:05 UTC 2020
Unique Patch ID:  23166117
Patch description:  "MERGE REQUEST ON TOP OF 19.0.0.0.0 FOR BUGS 28852325 29997937"
   Created on 3 Dec 2019, 18:28:56 hrs PST8PDT
   Bugs fixed:
     28852325, 29997937

Patch  30413137     : applied on Thu Jan 09 06:18:13 UTC 2020
Unique Patch ID:  23300563
Patch description:  "ORA-00600  INTERNAL ERROR CODE, ARGUMENTS  [2006]"
   Created on 3 Jan 2020, 04:09:07 hrs PST8PDT
   Bugs fixed:
     30413137
   This patch overlays patches:
     30557433, 29517242, 30557433, 29517242, 30557433
   This patch needs patches:
     30557433, 29517242, 30557433, 29517242, 30557433
   as prerequisites

Patch  30557433     : applied on Thu Jan 09 06:14:46 UTC 2020
Unique Patch ID:  23305305
Patch description:  "Database Release Update : 19.6.0.0.200114 (30557433)"
   Created on 6 Jan 2020, 19:07:34 hrs PST8PDT
   Bugs fixed:
     30545281, 8476681, 14735102, 17428816, 19080742, 19697993, 20313356
     21374587, 21965541, 23296836, 23606241, 24687075, 25756945, 25806201
     25883179, 25986062, 25997810, 26476244, 26611353, 26739322, 26777814
     26872233, 27036163, 27044169, 27101798, 27126938, 27195935, 27244999
     27254335, 27359766, 27369515, 27406105, 27411022, 27423500, 27439716
     27453490, 27458357, 27489107, 27666312, 27710072, 27729678, 27846298
     27880025, 27934711, 27935464, 27941110, 27957203, 27967484, 28064977
     28072567, 28109326, 28125947, 28129791, 28181021, 28189466, 28204262
     28205555, 28209985, 28210681, 28271258, 28271693, 28279456, 28294563
     28313275, 28319114, 28326928, 28350595, 28371123, 28373960, 28375383
     28379065, 28381939, 28386259, 28390273, 28395302, 28397317, 28402823
     28410431, 28431445, 28435333, 28454215, 28463226, 28475242, 28484299
     28489419, 28492006, 28498976, 28502773, 28513333, 28521330, 28530171
     28534475, 28538439, 28542455, 28546290, 28547068, 28547926, 28558645
     28561704, 28567417, 28567819, 28569897, 28572407, 28572533, 28572544
     28572667, 28572834, 28578945, 28587723, 28589509, 28593682, 28594086
     28597221, 28601957, 28605066, 28606598, 28612239, 28620697, 28625862
     28627033, 28636532, 28639299, 28643718, 28644549, 28645570, 28646200
     28646939, 28649388, 28655209, 28663782, 28672457, 28673945, 28692103
     28692275, 28694872, 28696373, 28705231, 28710385, 28710734, 28714461
     28715727, 28718469, 28719348, 28720204, 28720418, 28721497, 28722229
     28730079, 28734355, 28740708, 28742555, 28749853, 28752923, 28755011
     28758722, 28760206, 28765983, 28767240, 28769456, 28772390, 28774416
     28776811, 28777214, 28781754, 28785531, 28789531, 28791852, 28795551
     28795734, 28802734, 28804517, 28810381, 28811560, 28815123, 28815355
     28817449, 28819640, 28820669, 28821847, 28824482, 28827682, 28831971
     28833912, 28835937, 28836716, 28844738, 28849776, 28854004, 28855520
     28855922, 28857552, 28862532, 28863432, 28863487, 28867992, 28873575
     28875089, 28876253, 28876639, 28878865, 28882784, 28884931, 28887305
     28888327, 28889730, 28892794, 28897512, 28899663, 28901126, 28905457
     28905615, 28907196, 28912691, 28915561, 28917080, 28918429, 28919145
     28922227, 28922532, 28922608, 28925634, 28925880, 28927452, 28932914
     28933158, 28935293, 28936114, 28937717, 28938698, 28940179, 28940281
     28941901, 28942455, 28945421, 28945994, 28949888, 28950868, 28951533
     28952168, 28954762, 28955606, 28955883, 28956908, 28957292, 28957723
     28958088, 28959493, 28960863, 28962775, 28965084, 28965095, 28965231
     28965376, 28966444, 28974083, 28977322, 28983095, 28983486, 28985478
     28986207, 28986231, 28986257, 28986326, 28986481, 28988482, 28989306
     28993295, 28993353, 28994307, 28996376, 29000000, 29001305, 29001888
     29002488, 29002784, 29002927, 29003407, 29003738, 29006318, 29006621
     29007321, 29007353, 29007775, 29008035, 29008669, 29009513, 29010126
     29011936, 29012609, 29013475, 29013832, 29014076, 29015118, 29017265
     29018655, 29019121, 29021063, 29021352, 29022986, 29024054, 29024552
     29024732, 29026582, 29026606, 29027456, 29027694, 29027940, 29031575
     29031600, 29032234, 29032276, 29032457, 29032607, 29033052, 29033145
     29033200, 29033280, 29034587, 29037290, 29038528, 29038728, 29039089
     29039510, 29040739, 29043554, 29043651, 29043725, 29044763, 29044954
     29046482, 29047850, 29048178, 29048289, 29048498, 29048605, 29050357
     29050560, 29050765, 29050886, 29051702, 29051953, 29052726, 29053783
     29056024, 29056270, 29056560, 29056767, 29056894, 29059011, 29060216
     29061016, 29061959, 29062692, 29062848, 29062860, 29062868, 29110526
     29110783, 29110790, 29110797, 29110802, 29110805, 29111598, 29113282
     29113305, 29115857, 29117526, 29117642, 29118543, 29119077, 29120223
     29122224, 29122254, 29123297, 29123432, 29123482, 29124368, 29125036
     29125374, 29125380, 29126345, 29127957, 29128693, 29128935, 29129450
     29129497, 29129712, 29130219, 29131539, 29132869, 29132938, 29133470
     29134447, 29135383, 29135649, 29136111, 29138641, 29139956, 29141316
     29141341, 29141685, 29142609, 29142667, 29143516, 29144995, 29145214
     29145730, 29149829, 29150338, 29151520, 29152357, 29155099, 29157051
     29157389, 29158680, 29158899, 29159909, 29159936, 29160174, 29162095
     29163156, 29163415, 29163437, 29163524, 29163567, 29167111, 29167342
     29167374, 29167940, 29168137, 29168219, 29168433, 29169073, 29169215
     29170232, 29171683, 29171942, 29172618, 29172826, 29173140, 29173373
     29173817, 29174004, 29176318, 29177466, 29177543, 29177886, 29178385
     29180313, 29180455, 29180559, 29180893, 29181153, 29181231, 29181620
     29181743, 29181923, 29182019, 29182517, 29182901, 29183912, 29184297
     29184666, 29185193, 29186456, 29189302, 29189307, 29189889, 29190235
     29190474, 29190663, 29190740, 29191541, 29192419, 29192468, 29192685
     29193207, 29194205, 29194367, 29194493, 29194827, 29194981, 29195279
     29195337, 29195758, 29196725, 29198092, 29198913, 29199635, 29199733
     29200316, 29200700, 29201494, 29201539, 29201787, 29202104, 29202461
     29202850, 29203122, 29203166, 29203425, 29203443, 29203604, 29205281
     29205323, 29205419, 29205463, 29205767, 29205918, 29206109, 29206605
     29207073, 29208260, 29208732, 29211457, 29211724, 29212012, 29212433
     29212611, 29213320, 29213351, 29213613, 29213775, 29213850, 29213879
     29214561, 29214960, 29216312, 29216723, 29216746, 29216984, 29217294
     29217472, 29217828, 29217848, 29218570, 29219205, 29219273, 29220079
     29221248, 29221891, 29221942, 29222031, 29222784, 29223833, 29223859
     29223967, 29224065, 29224605, 29225076, 29225168, 29225758, 29227602
     29228869, 29229164, 29229754, 29229844, 29229955, 29230252, 29230565
     29231133, 29232117, 29232154, 29232449, 29233415, 29233810, 29233953
     29234123, 29236573, 29237538, 29237575, 29237744, 29240307, 29240759
     29241345, 29241651, 29242017, 29242884, 29243958, 29245137, 29245160
     29246163, 29247415, 29247712, 29247906, 29248495, 29248552, 29248835
     29248858, 29249412, 29249991, 29250059, 29250317, 29251259, 29253184
     29253871, 29254031, 29254930, 29255178, 29255273, 29255431, 29255435
     29256426, 29259119, 29259320, 29260452, 29260956, 29261547, 29261548
     29261906, 29262512, 29262887, 29265448, 29266248, 29266899, 29267292
     29268412, 29269171, 29269228, 29269825, 29270585, 29273539, 29273570
     29273735, 29273812, 29273847, 29274428, 29274564, 29274627, 29275461
     29276272, 29277317, 29278218, 29278684, 29279658, 29279751, 29279854
     29281527, 29281691, 29281796, 29282233, 29282898, 29285197, 29285503
     29285788, 29285956, 29286037, 29286229, 29287130, 29287705, 29292837
     29293072, 29293574, 29297863, 29297915, 29298220, 29299049, 29299082
     29299844, 29301463, 29301566, 29302963, 29303918, 29304781, 29306226
     29306713, 29307638, 29311528, 29311588, 29312310, 29312672, 29312734
     29312753, 29312889, 29313347, 29313417, 29313525, 29314539, 29314636
     29317756, 29318410, 29319441, 29321489, 29323946, 29324568, 29324735
     29325087, 29325105, 29325257, 29325765, 29325993, 29327044, 29329042
     29329087, 29329807, 29330361, 29331066, 29331209, 29331380, 29331493
     29332292, 29332395, 29332763, 29332771, 29333500, 29336843, 29337310
     29337742, 29338315, 29338348, 29338453, 29338780, 29338913, 29339101
     29339155, 29341209, 29343086, 29343861, 29345937, 29346057, 29346211
     29346943, 29347620, 29348176, 29350052, 29350762, 29351386, 29351662
     29351716, 29351735, 29351749, 29352298, 29352724, 29352867, 29352947
     29353271, 29353432, 29353821, 29353960, 29355654, 29356547, 29356704
     29356711, 29356752, 29358509, 29358828, 29360252, 29360285, 29360672
     29360911, 29360950, 29361319, 29361472, 29361801, 29363151, 29364171
     29364177, 29366940, 29367019, 29367561, 29368253, 29368310, 29372541
     29373418, 29373588, 29374179, 29375355, 29375941, 29375984, 29376346
     29377804, 29377986, 29378029, 29378834, 29378913, 29379978, 29382641
     29382784, 29382815, 29383695, 29384781, 29384854, 29384864, 29385429
     29385652, 29386502, 29386635, 29386660, 29387073, 29387274, 29388020
     29388072, 29388094, 29388524, 29388830, 29389889, 29390011, 29390435
     29390785, 29391030, 29391237, 29391849, 29391925, 29392966, 29393291
     29394014, 29394140, 29394749, 29395657, 29397954, 29397996, 29398488
     29398863, 29399046, 29399100, 29399121, 29399336, 29399938, 29402131
     29404483, 29405012, 29405462, 29405651, 29405996, 29407804, 29408853
     29409149, 29409455, 29410311, 29410834, 29411037, 29411469, 29412066
     29412269, 29416688, 29417173, 29417719, 29417884, 29418165, 29420834
     29421059, 29423003, 29423016, 29423156, 29423826, 29424999, 29426241
     29429017, 29429264, 29429466, 29429566, 29430524, 29430866, 29431192
     29431485, 29432176, 29434301, 29435474, 29435652, 29436454, 29436514
     29436727, 29437594, 29437712, 29438277, 29438736, 29439522, 29441196
     29443187, 29443250, 29444072, 29444282, 29444602, 29446669, 29448498
     29449477, 29449845, 29449852, 29450193, 29450421, 29450812, 29450936
     29451386, 29452251, 29452576, 29452936, 29452953, 29454978, 29455424
     29456714, 29457312, 29457370, 29457502, 29457807, 29457978, 29460252
     29461420, 29461791, 29462594, 29462767, 29462957, 29463047, 29463528
     29464616, 29464779, 29465177, 29467622, 29469565, 29470291, 29471860
     29472618, 29476473, 29481584, 29483452, 29483532, 29483626, 29483672
     29483685, 29483712, 29483723, 29483771, 29485099, 29486181, 29488894
     29489436, 29489546, 29490256, 29492127, 29492939, 29493122, 29494245
     29495057, 29495684, 29497311, 29497588, 29497696, 29498198, 29500257
     29500826, 29502561, 29503543, 29503631, 29503827, 29504492, 29504682
     29505668, 29507270, 29507616, 29508681, 29509777, 29510278, 29511611
     29514479, 29515134, 29515240, 29515476, 29515766, 29515834, 29516300
     29516727, 29516766, 29517168, 29517883, 29521187, 29521688, 29521748
     29521862, 29522358, 29522561, 29522662, 29523055, 29523511, 29524599
     29525467, 29525886, 29526966, 29527595, 29527610, 29528368, 29529147
     29530440, 29530515, 29530812, 29530909, 29531654, 29531836, 29532532
     29536342, 29536445, 29538631, 29541742, 29541769, 29542084, 29542449
     29542643, 29543034, 29543956, 29546817, 29547010, 29547867, 29548427
     29548687, 29548722, 29549071, 29549104, 29549154, 29549730, 29552773
     29553141, 29557144, 29557261, 29557336, 29557556, 29558238, 29558975
     29559187, 29559446, 29559908, 29559981, 29564592, 29564593, 29565611
     29580394, 29580983, 29581771, 29584261, 29584693, 29586143, 29587765
     29597536, 29597754, 29598039, 29598046, 29598233, 29599008, 29599300
     29601461, 29602831, 29603460, 29603884, 29604002, 29604257, 29607136
     29607797, 29608000, 29610506, 29611020, 29611991, 29615824, 29616244
     29616414, 29618074, 29618190, 29620042, 29622936, 29625065, 29625804
     29625876, 29626154, 29626732, 29628200, 29629430, 29629650, 29629681
     29629745, 29631749, 29632095, 29632265, 29632611, 29633697, 29633753
     29633936, 29634643, 29635427, 29635717, 29635990, 29637362, 29637526
     29638285, 29641736, 29643721, 29645349, 29648928, 29651183, 29651520
     29653132, 29653246, 29655668, 29656819, 29657422, 29657960, 29661028
     29661065, 29661722, 29663368, 29664087, 29664161, 29665940, 29667994
     29668005, 29669413, 29670782, 29671363, 29672507, 29676089, 29677051
     29677173, 29677733, 29677927, 29679856, 29681987, 29683039, 29687214
     29687459, 29687718, 29687763, 29689145, 29689255, 29692694, 29694869
     29695425, 29695841, 29696310, 29700125, 29700460, 29700770, 29703932
     29707099, 29707896, 29708915, 29710188, 29710858, 29713810, 29715220
     29716194, 29716491, 29717659, 29719146, 29720133, 29721418, 29725476
     29725781, 29726695, 29739576, 29741976, 29742223, 29746962, 29747493
     29747648, 29747653, 29748285, 29748336, 29748513, 29749471, 29750673
     29751094, 29753244, 29754951, 29755821, 29756274, 29756444, 29757099
     29757264, 29757651, 29758217, 29758661, 29761678, 29761837, 29761911
     29765393, 29766207, 29766503, 29766679, 29768899, 29770750, 29771032
     29771242, 29773197, 29773842, 29775393, 29779196, 29782211, 29782823
     29782866, 29784106, 29785239, 29787292, 29787766, 29791152, 29791880
     29793318, 29794462, 29795712, 29795957, 29796378, 29797726, 29802695
     29804875, 29805772, 29809837, 29812489, 29813503, 29815713, 29817278
     29821582, 29825525, 29827852, 29831196, 29834506, 29836096, 29838485
     29838773, 29839715, 29840619, 29841267, 29841687, 29843277, 29843692
     29844226, 29845530, 29846126, 29846645, 29848084, 29848849, 29849100
     29850930, 29851733, 29853485, 29858121, 29858376, 29865188, 29865658
     29869086, 29869404, 29869887, 29870065, 29871098, 29873665, 29875459
     29875565, 29877608, 29878076, 29881478, 29881839, 29882729, 29884958
     29887111, 29888621, 29890740, 29891916, 29893132, 29897418, 29897863
     29900203, 29902327, 29902330, 29903299, 29903454, 29906678, 29907942
     29909658, 29912286, 29914449, 29915217, 29915848, 29916975, 29920025
     29921318, 29926466, 29927756, 29928210, 29937565, 29938225, 29940373
     29942096, 29942554, 29943670, 29944035, 29944660, 29945645, 29946388
     29951620, 29956016, 29957493, 29961609, 29962248, 29962927, 29962939
     29966768, 29967223, 29968085, 29970298, 29971027, 29971888, 29989783
     29989845, 29991257, 29997326, 30003187, 30006159, 30006985, 30007797
     30008125, 30008214, 30009710, 30015070, 30019864, 30024618, 30029806
     30032376, 30033547, 30034456, 30035598, 30038392, 30040157, 30042490
     30043610, 30044507, 30047702, 30047765, 30051176, 30051783, 30053036
     30058149, 30058453, 30059106, 30059109, 30066352, 30074349, 30074472
     30075037, 30076197, 30078675, 30079949, 30080266, 30081580, 30083488
     30084971, 30085897, 30086992, 30090568, 30092859, 30095591, 30095952
     30097092, 30098251, 30099454, 30101186, 30104555, 30106748, 30110224
     30110370, 30110518, 30114489, 30114534, 30127522, 30127904, 30131645
     30135396, 30142907, 30149658, 30150606, 30154633, 30155837, 30159329
     30164714, 30165493, 30165503, 30170104, 30174401, 30175291, 30177597
     30178250, 30187866, 30189516, 30191274, 30193165, 30206493, 30218044
     30223712, 30223847, 30224950, 30235919, 30246179, 30247305, 30252098
     30252156, 30253608, 30255143, 30264405, 30266791, 30269428, 30274188
     30282591, 30299817, 30312094, 30318638, 30324180, 30342878, 30365745
     30389229, 30402386, 30408515, 30412188, 30453442, 30458593, 30474167
     30474774, 30485255, 30534827, 30641755

Patch  30489227     : applied on Thu Jan 09 06:12:50 UTC 2020
Unique Patch ID:  23305624
Patch description:  "OCW RELEASE UPDATE 19.6.0.0.0 (30489227)"
   Created on 7 Jan 2020, 03:37:45 hrs PST8PDT
   Bugs fixed:
     17787434, 25736599, 26675491, 27148384, 27222128, 27262781, 27572040
     27604329, 27760043, 27877830, 28302580, 28319989, 28406406, 28441307
     28470673, 28554809, 28621543, 28628631, 28642469, 28697242, 28697896
     28699321, 28704073, 28710663, 28747089, 28755846, 28762163, 28772816
     28785321, 28800508, 28805158, 28808652, 28815557, 28847541, 28847572
     28847655, 28852065, 28865162, 28870111, 28870496, 28871040, 28874416
     28874529, 28874678, 28877252, 28881191, 28881848, 28887933, 28888083
     28892095, 28911140, 28912188, 28917537, 28925250, 28925460, 28935956
     28940472, 28942694, 28951332, 28958624, 28963036, 28968779, 28973989
     28980448, 28984430, 28987100, 28995287, 29003207, 29003617, 29016294
     29018680, 29024876, 29026154, 29027933, 29030056, 29047127, 29051269
     29052850, 29053083, 29058476, 29111631, 29112455, 29117337, 29118754
     29123444, 29125708, 29125786, 29129476, 29130169, 29131772, 29132456
     29139727, 29146157, 29147849, 29149170, 29152603, 29152752, 29154631
     29154636, 29154829, 29159216, 29159661, 29160462, 29161923, 29169540
     29169739, 29170717, 29173618, 29181568, 29182920, 29183298, 29186091
     29191827, 29201143, 29201695, 29202442, 29209545, 29209972, 29210577
     29210610, 29210624, 29210683, 29213641, 29218185, 29219627, 29224294
     29225861, 29229839, 29231008, 29235934, 29242906, 29243749, 29244495
     29244766, 29244968, 29248723, 29249583, 29251564, 29254863, 29255616
     29257308, 29260224, 29261171, 29261695, 29266584, 29268887, 29271019
     29273360, 29274911, 29275362, 29276220, 29280752, 29282090, 29282666
     29285453, 29285621, 29288842, 29289634, 29290235, 29292232, 29293806
     29293928, 29294753, 29299830, 29307090, 29307109, 29311336, 29318127
     29329675, 29330791, 29338139, 29339299, 29342966, 29347106, 29351297
     29351881, 29357821, 29359713, 29360467, 29360775, 29367971, 29368725
     29376616, 29377086, 29379299, 29379381, 29380201, 29380253, 29380496
     29380527, 29381000, 29382296, 29385861, 29387212, 29390900, 29391301
     29392779, 29393649, 29395961, 29397888, 29398418, 29402110, 29407192
     29411931, 29413360, 29413448, 29416851, 29433434, 29438073, 29445982
     29450417, 29452365, 29457241, 29457319, 29460775, 29462569, 29465047
     29468589, 29470298, 29471399, 29473188, 29478378, 29485756, 29490266
     29495628, 29498957, 29499868, 29502953, 29504266, 29505022, 29505730
     29507560, 29510452, 29518947, 29524627, 29528119, 29529127, 29529530
     29529973, 29535802, 29537427, 29540165, 29542152, 29545235, 29549429
     29552763, 29555663, 29583036, 29585881, 29592188, 29593025, 29599431
     29599530, 29600906, 29601549, 29605539, 29618725, 29623009, 29632615
     29637215, 29641885, 29645874, 29655862, 29657866, 29659031, 29663838
     29671651, 29671851, 29671933, 29672162, 29672852, 29684210, 29684609
     29684672, 29686671, 29690422, 29692674, 29694497, 29721974, 29722328
     29741589, 29754146, 29760252, 29760705, 29769321, 29770006, 29770719
     29772541, 29780086, 29786752, 29797504, 29797626, 29798124, 29799836
     29805654, 29814993, 29817598, 29825944, 29828755, 29838281, 29839229
     29841704, 29851066, 29852422, 29853256, 29862652, 29862828, 29866585
     29867220, 29868392, 29876493, 29885967, 29893587, 29896074, 29909288
     29910893, 29921525, 29936936, 29939536, 29958570, 29972301, 29997804
     30006937, 30007337, 30009279, 30009884, 30012348, 30022613, 30028540
     30028697, 30032515, 30033476, 30039843, 30043518, 30047157, 30076461
     30080241, 30085531, 30123264, 30140462, 30142644, 30155486, 30159782
     30165554, 30191807, 30203000, 30210185, 30216942, 30226726, 30252076
     30300812, 30303080, 30422030, 30461079, 30461097, 30472602, 30482794
     30499905, 30559848, 3



--------------------------------------------------------------------------------

EOF

  patch_set = "19.6.0.0"
}
