// Copyright (c) 2017, 2024, Oracle and/or its affiliates. All rights reserved.
// Licensed under the Mozilla Public License v2.0

variable "tenancy_ocid" {}
variable "user_ocid" {}
variable "fingerprint" {}
variable "private_key_path" {}
variable "region" {}
variable "compartment_ocid" {}

variable "vulnerability_database_release" {
  default = "databaseRelease"
}

variable "vulnerability_state" {
  default = "AVAILABLE"
}

variable "dblm_display_name" {
  default = "displayName"
}

variable "vulnerability_scan_vulnerability_scan_type" {
  default = "CVE"
}



provider "oci" {
  tenancy_ocid     = var.tenancy_ocid
  user_ocid        = var.user_ocid
  fingerprint      = var.fingerprint
  private_key_path = var.private_key_path
  region           = var.region
}

data "oci_dblm_vulnerability" "test_vulnerabilities" {
  #Required
  compartment_id = var.compartment_ocid

  #Optional
  database_release = var.vulnerability_database_release
}

data "oci_dblm_vulnerability_vulnerabilities" "test_vulnerability_vulnerabilities" {
  #Required
  compartment_id = var.compartment_ocid

  #Optional
  database_release = var.vulnerability_database_release
  display_name = var.dblm_display_name
}

data "oci_dblm_vulnerability_resources" "test_vulnerability_resources" {
  #Required
  compartment_id = var.compartment_ocid

  #Optional
  display_name = var.dblm_display_name
}

data "oci_dblm_vulnerability_notifications" "test_vulnerability_notifications" {
  #Required
  compartment_id = var.compartment_ocid
}

data "oci_dblm_vulnerability_aggregated_vulnerability_data" "test_vulnerability_aggregated_vulnerability_data" {
  #Required
  compartment_id = var.compartment_ocid

  #Optional
  database_release = var.vulnerability_database_release
}

// To Create a Vulnerability Scan Resource
resource "oci_dblm_vulnerability_scan" "test_vulnerability_scan" {
	#Required
	compartment_id = var.compartment_ocid
	vulnerability_scan_type = var.vulnerability_scan_vulnerability_scan_type
}