// Copyright (c) 2017, 2024, Oracle and/or its affiliates. All rights reserved.

variable "tenancy_ocid" {}
variable "user_ocid" {}
variable "fingerprint" {}
variable "private_key_path" {}
variable "region" {}
variable "compartment_ocid" {}

variable "container_scan_recipe_defined_tags_value" {
  default = "value"
}

variable "container_scan_recipe_display_name" {
  default = "displayName"
}

variable "container_scan_recipe_freeform_tags" {
  default = { "bar-key" = "value" }
}

variable "container_scan_recipe_defined_tags" {
  default = "bar-key"
}

variable "container_scan_recipe_image_count" {
  default = 4
}

variable "container_scan_recipe_state" {
  default = "Active"
}

variable "host_scan_instance_ocids" {
  default = []
}

variable "container_repo_name" {

}

variable "vault_secret_ocid" {
  default = "some-secret-ocid"
}

provider "oci" {
  tenancy_ocid     = var.tenancy_ocid
  user_ocid        = var.user_ocid
  fingerprint      = var.fingerprint
  private_key_path = var.private_key_path
  region           = var.region
}

resource "oci_vulnerability_scanning_host_scan_recipe" "test_host_scan_recipe" {
    #Required
    agent_settings {
      #Required
      scan_level = "NONE"

      #Optional
      agent_configuration {
        #Required
        vendor = "OCI"

        #Optional
        cis_benchmark_settings {

          #Optional
          scan_level = "NONE"
        }

        #Optional
        vendor_type = "OCI"
      }
    }
    compartment_id = var.compartment_ocid
    port_settings {
      #Required
      scan_level = "NONE"
    }
    schedule {
      #Required
      type = "DAILY"

      #Optional
      day_of_week = "SUNDAY"
    }

    #Optional
    display_name = "TestHostScanRecipe"
}

resource "oci_vulnerability_scanning_host_scan_recipe" "test_qualys_host_scan_recipe" {
  #Required
  agent_settings {
    #Required
    scan_level = "NONE"

    #Optional
    agent_configuration {
      #Required
      vendor = "QUALYS"

      #Required
      should_un_install = false

      #Required
      vault_secret_id = var.vault_secret_ocid

      #Optional
      vendor_type = "QUALYS"

    }
  }
  compartment_id = var.compartment_ocid
  port_settings {
    #Required
    scan_level = "NONE"
  }
  schedule {
    #Required
    type = "DAILY"

    #Optional
    day_of_week = "SUNDAY"
  }

  #Optional
  display_name = "TestHostScanRecipe"
}

resource "oci_vulnerability_scanning_host_scan_target" "test_host_scan_target" {
  #Required
  compartment_id = var.compartment_ocid
  host_scan_recipe_id = oci_vulnerability_scanning_host_scan_recipe.test_host_scan_recipe.id
  target_compartment_id = var.compartment_ocid

  #Optional
  description = "Test target example"
  display_name = "TestHostScanTarget"
  freeform_tags = {"bar-key"= "value"}
  instance_ids = var.host_scan_instance_ocids
}

resource "oci_vulnerability_scanning_container_scan_recipe" "test_container_scan_recipe" {
  #Required
  compartment_id = var.compartment_ocid
  scan_settings {
    #Required
    scan_level = "NONE"
  }

  #Optional
  display_name  = var.container_scan_recipe_display_name
  freeform_tags = var.container_scan_recipe_freeform_tags
  image_count   = var.container_scan_recipe_image_count
}

resource "oci_vulnerability_scanning_container_scan_target" "test_container_scan_target" {
  #Required
  compartment_id = var.compartment_ocid
  container_scan_recipe_id = oci_vulnerability_scanning_container_scan_recipe.test_container_scan_recipe.id
  target_registry {
    #Required
    compartment_id = var.compartment_ocid
    type = "OCIR"

    #Optional
    url = "https://us-ashburn-1.ocir.io/"
  }

  #Optional
  description = "Container scan target example"
  display_name = "TestContainerScanTarget"
}

data "oci_vulnerability_scanning_container_scan_recipes" "test_container_scan_recipes" {
  #Required
  compartment_id = var.compartment_ocid

  #Optional
  display_name = var.container_scan_recipe_display_name
  state        = var.container_scan_recipe_state
}